@@ -16,6 +16,9 @@
  *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  */ 
 
+#ifndef MAPPING_H
+#define MAPPING_H
+
 struct mapping_t
 {
   char *name;
@@ -26,3 +29,5 @@ char *mutt_getnamebyvalue (int, const struct mapping_t *);
 char *mutt_compile_help (char *, size_t, int, struct mapping_t *);
 
 int mutt_getvaluebyname (const char *, const struct mapping_t *);
+
+#endif
